{% extends 'store/layout/layout.html' %}
{% load static %}


{% block title %}Products{% endblock %}
{% block style %}{% endblock %}


{% block body %}
{% endblock %}


{% block script %}
{% endblock %}