<div style="display: none;">
    <button class="btn btn-primary" type="button" data-bs-toggle="offcanvas" data-bs-target="#cartOffcanvas" aria-controls="cartOffcanvas" id="cartOffcanvasDisplayBtn">
        cart offcanvas
    </button>
</div>


<div class="offcanvas offcanvas-start" tabindex="-1" id="cartOffcanvas" aria-labelledby="cartOffcanvasLabel">
    <div class="offcanvas-header bg-dark text-white">
        <h5 class="offcanvas-title" id="cartOffcanvasLabel">Cart</h5>
        <button type="button" class="btn-close btn-close-white" data-bs-dismiss="offcanvas" aria-label="Close" id="cartOffcanvasCloseBtn"></button>
    </div>
    <div class="offcanvas-body mx-2" id="cartOffcanvasDiv"></div>
</div>